--- a/idlehomescreen/inc/xneditmode.h Tue Apr 27 16:26:12 2010 +0300
+++ b/idlehomescreen/inc/xneditmode.h Tue May 11 16:02:39 2010 +0300
@@ -24,6 +24,7 @@
// Forward declarations
class CXnUiEngine;
class CXnViewManager;
+class CXnPluginData;
class CXnNode;
class CFbsBitGc;
class CFbsBitmap;
@@ -134,9 +135,9 @@
* Organizing starts using drag and drop.
*
* @since Series 60 5.0
* @param aNode Node to drag.
*/
- void StartDragL( CXnNode& aNode );
+ void StartDragL( const CXnPluginData& aPlugin );
/**
* Reset the dragging state and deletes screenshot bitmaps.
@@ -134,9 +135,9 @@
*
* @since Series 60 5.0
- * @param aNode Node to drag.
+ * @param aPlugin Plugin to drag.
*/